.. API reference page, created 9/20/21 (inspired by seaborn)

.. currentmodule:: ctdcal

API reference
=============

.. autosummary::
   :toctree: generated/
   :template: custom-module-template.rst
   :recursive:

   convert
   ctd_plots
   equations_sbe
   fit_ctd
   flagging
   merge_codes
   odf_io
   oxy_fitting
   process_bottle
   process_ctd
   report_ctd
   rinko
   sbe_reader